==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/SnmpTrapCore/src/com/clustercontrol/snmptrap/util/EjbConnectionManager.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.util;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import org.jnp.interfaces.NamingContext;

import com.clustercontrol.snmptrap.ejb.session.MonitorSnmpTrapController;
import com.clustercontrol.snmptrap.ejb.session.MonitorSnmpTrapControllerHome;
import com.clustercontrol.util.LoginManager;

/**
 * EJBȤΥͥ륯饹
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class EjbConnectionManager {
    public static final String KEY_EJB_URL = "ejbUrl";
    public static final String VALUE_EJB_URL = "jnp://localhost:1099";
    private static EjbConnectionManager m_instance = null;
    private NamingContext m_ctx = null;

    /**
     * Υ֥Ȥޤ
     * 
     * @return ConnectionManager ͥޥ͡
     */
    public static EjbConnectionManager getConnectionManager() {
        if (m_instance == null) {
            m_instance = new EjbConnectionManager();
        }
        return m_instance;
    }

    private EjbConnectionManager() {

    }

    /**
     * MonitorSnmpTrapControllerޤ
     * 
     * @return MonitorSnmpTrapController
     */
    public synchronized MonitorSnmpTrapController getSnmpTrapController() {
        try {
            m_ctx = LoginManager.getContextManager().getNamingContext();
        } catch (NamingException e) {
            return null;
        }

        MonitorSnmpTrapControllerHome home;
        try {
            home = (MonitorSnmpTrapControllerHome) m_ctx
                    .lookup(MonitorSnmpTrapControllerHome.JNDI_NAME);
            return home.create();
        } catch (NamingException e) {
        	e.printStackTrace();
        } catch (RemoteException e) {
        } catch (CreateException e) {
        }
        m_ctx = null;
        return null;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/SnmpTrapCore/src/com/clustercontrol/snmptrap/util/EjbConnectionManager.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.util;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import org.jnp.interfaces.NamingContext;

import com.clustercontrol.snmptrap.ejb.session.MonitorSnmpTrapController;
import com.clustercontrol.snmptrap.ejb.session.MonitorSnmpTrapControllerHome;
import com.clustercontrol.util.LoginManager;

/**
 * EJBとのコネクションを管理するクラス
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class EjbConnectionManager {
    public static final String KEY_EJB_URL = "ejbUrl";
    public static final String VALUE_EJB_URL = "jnp://localhost:1099";
    private static EjbConnectionManager m_instance = null;
    private NamingContext m_ctx = null;

    /**
     * このオブジェクトを取得します。
     * 
     * @return ConnectionManager コネクションマネージャ
     */
    public static EjbConnectionManager getConnectionManager() {
        if (m_instance == null) {
            m_instance = new EjbConnectionManager();
        }
        return m_instance;
    }

    private EjbConnectionManager() {

    }

    /**
     * MonitorSnmpTrapControllerを取得します。
     * 
     * @return MonitorSnmpTrapController
     */
    public synchronized MonitorSnmpTrapController getSnmpTrapController() {
        try {
            m_ctx = LoginManager.getContextManager().getNamingContext();
        } catch (NamingException e) {
            return null;
        }

        MonitorSnmpTrapControllerHome home;
        try {
            home = (MonitorSnmpTrapControllerHome) m_ctx
                    .lookup(MonitorSnmpTrapControllerHome.JNDI_NAME);
            return home.create();
        } catch (NamingException e) {
        	e.printStackTrace();
        } catch (RemoteException e) {
        } catch (CreateException e) {
        }
        m_ctx = null;
        return null;
    }
}
